local E, L, V, P, G = unpack(ElvUI)
local MOGUI = E:NewModule('MaximumOverdriveGamingUI', 'AceHook-3.0', 'AceEvent-3.0', 'AceTimer-3.0', "AceConsole-3.0");

local LSM = LibStub('LibSharedMedia-3.0')
local EP = LibStub('LibElvUIPlugin-1.0')
local addon, ns = ...

local _G = _G
local pairs, print = pairs, print
local format = string.format
local CreateFrame = CreateFrame
local C_TimerAfter = C_Timer.After

MOGUI.Config = {}
MOGUI["styles"] = {}
MOGUI["softGlow"] = {}
MOGUI.TexCoords = {.08, 0.92, -.04, 0.92}
MOGUI.Title = format('|cff00c0fa%s |r', 'MOGUI')
MOGUI.Version = GetAddOnMetadata('ElvUI_MOGUI', 'Version')
MOGUI.NewSign = '|TInterface\\OptionsFrame\\UI-OptionsFrame-NewFeatureIcon:14:14|t'
BINDING_HEADER_MOGUI = MOGUI.Title

local classColor = E.myclass == 'PRIEST' and E.PriestColors or (CUSTOM_CLASS_COLORS and CUSTOM_CLASS_COLORS[E.myclass] or RAID_CLASS_COLORS[E.myclass])

function MOGUI:cOption(name)
	local color = '|cff00c0fa%s |r'
	return (color):format(name)
end

function MOGUI:PrintURL(url) -- Credit: Azilroka
	return format("|cFF00c0fa[|Hurl:%s|h%s|h]|r", url, url)
end

function MOGUI:AddOptions()
	for _, func in pairs(MOGUI.Config) do
		func()
	end
end

function MOGUI:LoadOptions()
	E:ToggleConfig(); LibStub("AceConfigDialog-3.0-ElvUI"):SelectGroup("ElvUI", "mogui")
end

function MOGUI:LoadCommands()
	self:RegisterChatCommand("mogui", "LoadOptions")
	self:RegisterChatCommand("moguisetup", "SetupMOGUI")
end

local function CreateSplashScreen()
	local f = CreateFrame('Frame', 'MOGUISplashScreen', E.UIParent)
	f:Size(300, 150)
	f:SetPoint('CENTER')
	f:SetFrameStrata('TOOLTIP')
	f:SetAlpha(0)

	f.bg = f:CreateTexture(nil, 'BACKGROUND')
	f.bg:SetTexture([[Interface\LevelUp\LevelUpTex]])
	f.bg:SetPoint('BOTTOM')
	f.bg:Size(400, 200)
	f.bg:SetTexCoord(0.00195313, 0.63867188, 0.03710938, 0.23828125)
	f.bg:SetVertexColor(1, 1, 1, 0.7)

	f.lineTop = f:CreateTexture(nil, 'BACKGROUND')
	f.lineTop:SetDrawLayer('BACKGROUND', 2)
	f.lineTop:SetTexture([[Interface\LevelUp\LevelUpTex]])
	f.lineTop:SetPoint("TOP")
	f.lineTop:Size(418, 7)
	f.lineTop:SetTexCoord(0.00195313, 0.81835938, 0.01953125, 0.03320313)

	f.lineBottom = f:CreateTexture(nil, 'BACKGROUND')
	f.lineBottom:SetDrawLayer('BACKGROUND', 2)
	f.lineBottom:SetTexture([[Interface\LevelUp\LevelUpTex]])
	f.lineBottom:SetPoint("BOTTOM")
	f.lineBottom:Size(418, 7)
	f.lineBottom:SetTexCoord(0.00195313, 0.81835938, 0.01953125, 0.03320313)

	f.logo = f:CreateTexture(nil, 'OVERLAY')
	f.logo:Size(256, 128)
	f.logo:SetTexture('Interface\\AddOns\\ElvUI_MOGUI\\media\\textures\\logo_MOGUI.tga')
	f.logo:Point('CENTER', f, 'CENTER')

	f.version = f:CreateFontString(nil, 'OVERLAY')
	f.version:FontTemplate(nil, 12, nil)
	f.version:Point('TOP', f.logo, 'BOTTOM')
	f.version:SetFormattedText("v%s", MOGUI.Version)
end

local function HideSplashScreen()
	MOGUISplashScreen:Hide()
end

local function FadeSplashScreen()
	E:Delay(2, function()
		E:UIFrameFadeOut(MOGUISplashScreen, 2, 1, 0)
		MOGUISplashScreen.fadeInfo.finishedFunc = HideSplashScreen
	end)
end

local function ShowSplashScreen()
	E:UIFrameFadeIn(MOGUISplashScreen, 4, 0, 1)
	MOGUISplashScreen.fadeInfo.finishedFunc = FadeSplashScreen
end

function MOGUI:Initialize()
	if E.db.MOGUI.general.splashScreen then
		CreateSplashScreen()
	end

	-- run install when ElvUI install finishes
    if E.private.install_complete == E.version and E.private.MOGUI.install_complete == nil then
		E:GetModule("PluginInstaller"):Queue(MOGUI.MOGUIInstallTable)
	end
	
	-- Show Splash Screen only if the install is completed
	if (E.db.MOGUI.installed == true and E.db.MOGUI.general.splashScreen) then C_TimerAfter(6, ShowSplashScreen) end

	-- run the setup again when a profile gets deleted.
	local profileKey = ElvDB.profileKeys[E.myname..' - '..E.myrealm]
	if ElvDB.profileKeys and profileKey == nil then
		E:GetModule("PluginInstaller"):Queue(MOGUI.MOGUIInstallTable)
	end
	

	if E.db.MOGUI.general.loginMessage then
		print(MOGUI.Title..format('v|cff00c0fa%s|r',MOGUI.Version)..L[' is loaded. For any issues or suggestions, please visit ']..MOGUI:PrintURL('https://git.tukui.org/MaximumOverdrive/ThinkTankUI-Remastered/issues'))
	end
	EP:RegisterPlugin(addon, self.AddOptions)

end

local function InitializeCallback()
	MOGUI:Initialize()
end

E:RegisterModule(MOGUI:GetName(), InitializeCallback)